"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsIamRoleChainedSessionData = void 0;
const session_data_1 = require("./session-data");
const session_type_1 = require("../../models/session-type");
class AwsIamRoleChainedSessionData extends session_data_1.SessionData {
    /**
     * @param parentSessionId - the ID of the parent Leapp Session this Leapp Session is going to be assumed from.
     * @param profileId - ID of the Named Profile that is going to be associated with the Leapp Session; it refers to an internal ID rather than the name assigned by the user.
     * When instantiating this class, use the method getProfileIdByName() to obtain the Named Profile ID by passing its name.
     * @param region - the region associated with the Leapp Session
     * @param roleArn - the ARN of the Role that has to be assumed via {@link https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html|Role Chaining}
     * @param sessionName - the name of the Leapp Session
     */
    constructor(parentSessionId, profileId, region, roleArn, sessionName) {
        super(session_type_1.SessionType.awsIamRoleChained);
        this.parentSessionId = parentSessionId;
        this.profileId = profileId;
        this.region = region;
        this.roleArn = roleArn;
        this.sessionName = sessionName;
    }
    getCreationRequest() {
        return {
            parentSessionId: this.parentSessionId,
            profileId: this.profileId,
            region: this.region,
            roleArn: this.roleArn,
            sessionName: this.sessionName,
        };
    }
}
exports.AwsIamRoleChainedSessionData = AwsIamRoleChainedSessionData;
//# sourceMappingURL=aws-iam-role-chained-session-data.js.map