"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsIamRoleFederatedSessionData = void 0;
const session_data_1 = require("./session-data");
const session_type_1 = require("../../models/session-type");
class AwsIamRoleFederatedSessionData extends session_data_1.SessionData {
    /**
     * @param idpArn - the ARN of the AWS IAM Identity Provider used to federate the external Identity Provider with the Service Provider, i.e. AWS.
     * @param idpUrlId - ID of the IdP URL that is going to be associated with the Leapp Session; it refers to an internal ID rather than the name assigned by the user.
     * When instantiating this class, use the method getIdpUrlIdByUrl() to obtain the IdP URL ID by passing the URL.
     * @param profileId - ID of the Named Profile that is going to be associated with the Leapp Session; it refers to an internal ID rather than the name assigned by the user.
     * When instantiating this class, use the method getProfileIdByName() to obtain the Named Profile ID by passing its name.
     * @param region - the region associated with the Leapp Session
     * @param roleArn - the ARN of the Role that has to be assumed through Leapp via SAML 2.0 federation between the external IdP and AWS.
     * The Role trusts the AWS IAM Identity Provider (identified by the idpArn parameter) via a {@link https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html|Trust Policy}.
     * @param sessionName - the name of the Leapp Session
     */
    constructor(idpArn, idpUrlId, profileId, region, roleArn, sessionName) {
        super(session_type_1.SessionType.awsIamRoleFederated);
        this.idpArn = idpArn;
        this.idpUrlId = idpUrlId;
        this.profileId = profileId;
        this.region = region;
        this.roleArn = roleArn;
        this.sessionName = sessionName;
    }
    getCreationRequest() {
        return {
            profileId: this.profileId,
            region: this.region,
            sessionName: this.sessionName,
            roleArn: this.roleArn,
            idpUrl: this.idpUrlId,
            idpArn: this.idpArn,
        };
    }
}
exports.AwsIamRoleFederatedSessionData = AwsIamRoleFederatedSessionData;
//# sourceMappingURL=aws-iam-role-federated-session-data.js.map