"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsIamUserSessionData = void 0;
const session_data_1 = require("./session-data");
const session_type_1 = require("../../models/session-type");
class AwsIamUserSessionData extends session_data_1.SessionData {
    /**
     * @param profileId - ID of the Named Profile that is going to be associated with the Leapp Session; it refers to an internal ID rather than the name assigned by the user.
     * When instantiating this class, use the method getProfileIdByName() to obtain the Named Profile ID by passing its name.
     * @param region - the region that is going to be associated with the Leapp Session
     * @param sessionName - the name of the Leapp Session
     * @param accessKey - the Access Key ID associated with the IAM User. See {@link https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html|AWS documentation}.
     * @param secretKey - the Secret Access Key associated with the IAM User. See {@link https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html|AWS documentation}.
     */
    constructor(profileId, region, sessionName, accessKey, secretKey) {
        super(session_type_1.SessionType.awsIamUser);
        this.profileId = profileId;
        this.region = region;
        this.sessionName = sessionName;
        this.accessKey = accessKey;
        this.secretKey = secretKey;
    }
    getCreationRequest() {
        return {
            profileId: this.profileId,
            region: this.region,
            sessionName: this.sessionName,
            accessKey: this.accessKey,
            secretKey: this.secretKey,
        };
    }
}
exports.AwsIamUserSessionData = AwsIamUserSessionData;
//# sourceMappingURL=aws-iam-user-session-data.js.map