"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PluginEnvironment = exports.EnvironmentType = void 0;
const log_service_1 = require("../services/log-service");
const constants_1 = require("../models/constants");
var EnvironmentType;
(function (EnvironmentType) {
    EnvironmentType["desktopApp"] = "desktop-app";
    EnvironmentType["cli"] = "cli";
})(EnvironmentType = exports.EnvironmentType || (exports.EnvironmentType = {}));
class PluginEnvironment {
    constructor(environmentType, providerService) {
        this.environmentType = environmentType;
        this.providerService = providerService;
        if (environmentType === EnvironmentType.desktopApp) {
            this.nativeService = providerService.appNativeService;
            this.openExternalUrlService = providerService.windowService;
        }
        else {
            this.nativeService = providerService.cliNativeService;
            this.openExternalUrlService = providerService.cliOpenWebConsoleService;
        }
    }
    log(message, level, display) {
        this.providerService.logService.log(new log_service_1.LoggedEntry(message, this, level, display));
    }
    fetch(url) {
        return this.nativeService.fetch(url);
    }
    openExternalUrl(loginUrl) {
        this.openExternalUrlService.openExternalUrl(loginUrl);
    }
    getProfileIdByName(profileName) {
        return this.providerService.namedProfileService.getProfileIdByName(profileName);
    }
    getIdpUrlIdByUrl(url) {
        return this.providerService.idpUrlService.getIdpUrlIdByUrl(url);
    }
    async openTerminal(command, env) {
        let exportedEnvVars = "";
        for (const [key, value] of Object.entries(env)) {
            exportedEnvVars = exportedEnvVars.concat(`export ${key}=${value};\n`);
        }
        this.providerService.fileService.writeFileSync(this.nativeService.os.homedir() + "/" + constants_1.constants.pluginEnvFileDestination, exportedEnvVars);
        this.providerService.executeService
            .openTerminalFromPlugin(command, env)
            .then(() => {
            if (this.nativeService.process.platform === "darwin")
                this.nativeService.rimraf(this.nativeService.os.homedir() + "/" + constants_1.constants.pluginEnvFileDestination, {}, () => { });
        })
            .catch((_) => {
            if (this.nativeService.process.platform === "darwin") {
                this.nativeService.rimraf(this.nativeService.os.homedir() + "/" + constants_1.constants.pluginEnvFileDestination, {}, () => { });
            }
        });
    }
    async createSession(createSessionData) {
        const sessionService = this.providerService.sessionFactory.getSessionService(createSessionData.sessionType);
        return await sessionService.create(createSessionData.getCreationRequest());
    }
    async cloneSession(session) {
        const sessionService = this.providerService.sessionFactory.getSessionService(session.type);
        const createSessionData = await sessionService.getCloneRequest(session);
        return await sessionService.create(createSessionData);
    }
    async updateSession(updateSessionData, session) {
        const sessionService = this.providerService.sessionFactory.getSessionService(session.type);
        return await sessionService.update(session.sessionId, updateSessionData.getCreationRequest());
    }
    async generateCredentials(session) {
        const sessionService = this.providerService.sessionFactory.getSessionService(session.type);
        return await sessionService.generateCredentials(session.sessionId);
    }
}
exports.PluginEnvironment = PluginEnvironment;
//# sourceMappingURL=plugin-environment.js.map