"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AwsSamlAssertionExtractionService = void 0;
const cloud_provider_type_1 = require("../models/cloud-provider-type");
const log_service_1 = require("./log-service");
const authenticationUrlRegexes = new Map([
    [
        cloud_provider_type_1.CloudProviderType.aws,
        [
            /^https:\/\/.*\.onelogin\.com\/.*/,
            /^https:\/\/.*\/adfs\/ls\/idpinitiatedsignon.*loginToRp=urn:amazon:webservices.*/,
            /^https:\/\/login\.okta\.com\/.*/,
            /^https:\/\/accounts\.google\.com\/ServiceLogin.*/,
            /^https:\/\/login\.microsoftonline\.com\/*.*\/oauth2\/authorize.*/,
            /^https:\/\/.+\.auth0\.com\/u\/login\/.+/,
            /^https:\/\/.*[/auth]?\/realms\/.*\/protocol\/saml\/clients\/.*/,
            /^https:\/\/console\.jumpcloud\.com\/login.*/,
            /^https:\/\/accounts\.google\.com\/AccountChooser.*/,
        ],
    ],
]);
const samlAssertionRegexes = new Map([
    [cloud_provider_type_1.CloudProviderType.aws, [/^https:\/\/signin\.aws\.amazon\.com\/saml/, /^https:\/\/signin\.amazonaws-us-gov\.com\/saml/]],
]);
class AwsSamlAssertionExtractionService {
    isAuthenticationUrl(cloudProvider, url) {
        return authenticationUrlRegexes.get(cloudProvider).some((regex) => regex.test(url));
    }
    isSamlAssertionUrl(cloudProvider, url) {
        return samlAssertionRegexes.get(cloudProvider).some((regex) => regex.test(url));
    }
    extractAwsSamlResponse(responseHookDetails) {
        try {
            let rawData = responseHookDetails.uploadData[0].bytes.toString();
            const n = rawData.lastIndexOf("SAMLResponse=");
            const n2 = rawData.lastIndexOf("&RelayState=");
            rawData = n2 !== -1 ? rawData.substring(n + 13, n2) : rawData.substring(n + 13);
            return decodeURIComponent(rawData);
        }
        catch (err) {
            throw new log_service_1.LoggedException(err.message, this, log_service_1.LogLevel.warn);
        }
    }
}
exports.AwsSamlAssertionExtractionService = AwsSamlAssertionExtractionService;
//# sourceMappingURL=aws-saml-assertion-extraction-service.js.map