import { JsonCache, SerializedRefreshTokenEntity } from "@azure/msal-node";
import { INativeService } from "../interfaces/i-native-service";
import { SerializedAccountEntity } from "@azure/msal-node/dist/cache/serializer/SerializerTypes";
import { IKeychainService } from "../interfaces/i-keychain-service";
export interface AzureSubscription {
    id: string;
    name: string;
    state: string;
    user: {
        name: string;
        type: string;
    };
    isDefault: boolean;
    tenantId: string;
    environmentName: string;
    homeTenantId: string;
    managedByTenants: any[];
}
export interface AzureProfile {
    installationId: string;
    subscriptions: AzureSubscription[];
}
export declare enum DataProtectionScope {
    currentUser = "CurrentUser",
    localMachine = "LocalMachine"
}
export interface AzureSecrets {
    profile: AzureProfile;
    account: [string, SerializedAccountEntity];
    refreshToken: [string, SerializedRefreshTokenEntity];
}
export declare class AzurePersistenceService {
    private iNativeService;
    private keychainService;
    constructor(iNativeService: INativeService, keychainService: IKeychainService);
    loadMsalCache(): Promise<JsonCache>;
    saveMsalCache(cache: JsonCache): Promise<void>;
    loadProfile(): Promise<AzureProfile>;
    saveProfile(profile: AzureProfile): Promise<void>;
    getAzureSecrets(integrationId: string): Promise<AzureSecrets>;
    setAzureSecrets(integrationId: string, secrets: AzureSecrets): Promise<void>;
    deleteAzureSecrets(integrationId: string): Promise<void>;
    private getMsalCacheLocation;
    private getProfileLocation;
    private getAccountKeychainKey;
    private getRefreshTokenKeychainKey;
    private getProfileKeychainKey;
}
