"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CloudProviderService = exports.createNewIdpUrlFieldChoice = void 0;
const access_method_1 = require("../models/access-method");
const access_method_field_1 = require("../models/access-method-field");
const access_method_field_type_1 = require("../models/access-method-field-type");
const cloud_provider_type_1 = require("../models/cloud-provider-type");
const session_type_1 = require("../models/session-type");
const aws_assumer_session_types_1 = require("./aws-assumer-session-types");
const field_choice_1 = require("./field-choice");
const idp_url_access_method_field_1 = require("../models/idp-url-access-method-field");
const integration_method_1 = require("../models/integration-method");
const integration_type_1 = require("../models/integration-type");
const aws_sso_integration_service_1 = require("./integration/aws-sso-integration-service");
const azure_integration_service_1 = require("./integration/azure-integration-service");
exports.createNewIdpUrlFieldChoice = "CreateNewIdpUrlFieldChoice";
class CloudProviderService {
    constructor(awsCoreService, azureCoreService, namedProfilesService, idpUrlService, repository) {
        this.awsCoreService = awsCoreService;
        this.azureCoreService = azureCoreService;
        this.namedProfilesService = namedProfilesService;
        this.idpUrlService = idpUrlService;
        this.repository = repository;
    }
    availableCloudProviders() {
        return [cloud_provider_type_1.CloudProviderType.aws, cloud_provider_type_1.CloudProviderType.azure];
    }
    creatableAccessMethods(cloudProviderType) {
        return this.accessMethodMap.get(cloudProviderType).filter((accessMethod) => accessMethod.creatable);
    }
    creatableIntegrationMethods() {
        const awsRegionChoices = this.getAwsRegionChoices();
        return [
            new integration_method_1.IntegrationMethod(integration_type_1.IntegrationType.awsSso, "AWS Single Sign-On", [
                new access_method_field_1.AccessMethodField("alias", "Insert integration alias", access_method_field_type_1.AccessMethodFieldType.input, undefined, aws_sso_integration_service_1.AwsSsoIntegrationService.validateAlias),
                new access_method_field_1.AccessMethodField("portalUrl", "Insert the portal url", access_method_field_type_1.AccessMethodFieldType.input, undefined, aws_sso_integration_service_1.AwsSsoIntegrationService.validatePortalUrl),
                new access_method_field_1.AccessMethodField("region", "Select region", access_method_field_type_1.AccessMethodFieldType.list, awsRegionChoices),
            ]),
            new integration_method_1.IntegrationMethod(integration_type_1.IntegrationType.azure, "Azure", [
                new access_method_field_1.AccessMethodField("alias", "Insert integration alias", access_method_field_type_1.AccessMethodFieldType.input, undefined, azure_integration_service_1.AzureIntegrationService.validateAlias),
                new access_method_field_1.AccessMethodField("tenantId", "Insert the tenant id", access_method_field_type_1.AccessMethodFieldType.input, undefined, azure_integration_service_1.AzureIntegrationService.validateTenantId),
            ]),
        ];
    }
    getSessionTypeMap() {
        const accessMethods = [...this.accessMethodMap.values()].flatMap((method) => method);
        return new Map(accessMethods.map((accessMethod) => [accessMethod.sessionType, accessMethod.label]));
    }
    availableRegions(sessionType) {
        var _a;
        return (_a = this.regionMap.get(sessionType)) !== null && _a !== void 0 ? _a : [];
    }
    get accessMethodMap() {
        const awsRegionChoices = this.getAwsRegionChoices();
        const awsNamedProfileChoices = this.getAwsNamedProfileChoices();
        const idpUrlChoices = this.getIdpUrls();
        const awsAssumerSessionChoices = this.getAwsAssumerSessionChoices();
        const azureLocationChoices = this.getAzureLocationChoices();
        return new Map([
            [
                cloud_provider_type_1.CloudProviderType.aws,
                [
                    new access_method_1.AccessMethod(session_type_1.SessionType.awsIamUser, "IAM User", [
                        new access_method_field_1.AccessMethodField("sessionName", "Insert session alias", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("accessKey", "Insert Access Key ID", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("secretKey", "Insert Secret Access Key", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("region", "Select region", access_method_field_type_1.AccessMethodFieldType.list, awsRegionChoices),
                        new access_method_field_1.AccessMethodField("mfaDevice", "Insert Mfa Device ARN", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("profileId", "Select the Named Profile", access_method_field_type_1.AccessMethodFieldType.list, awsNamedProfileChoices),
                    ], true),
                    new access_method_1.AccessMethod(session_type_1.SessionType.awsIamRoleFederated, "IAM Role Federated", [
                        new access_method_field_1.AccessMethodField("sessionName", "Insert session alias", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("region", "Select region", access_method_field_type_1.AccessMethodFieldType.list, awsRegionChoices),
                        new access_method_field_1.AccessMethodField("roleArn", "Insert Role ARN", access_method_field_type_1.AccessMethodFieldType.input),
                        new idp_url_access_method_field_1.IdpUrlAccessMethodField("idpUrl", "Select the SAML 2.0 Url", access_method_field_type_1.AccessMethodFieldType.list, idpUrlChoices),
                        new access_method_field_1.AccessMethodField("idpArn", "Insert the AWS Identity Provider ARN", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("profileId", "Select the Named Profile", access_method_field_type_1.AccessMethodFieldType.list, awsNamedProfileChoices),
                    ], true),
                    new access_method_1.AccessMethod(session_type_1.SessionType.awsIamRoleChained, "IAM Role Chained", [
                        new access_method_field_1.AccessMethodField("sessionName", "Insert session alias", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("region", "Select region", access_method_field_type_1.AccessMethodFieldType.list, awsRegionChoices),
                        new access_method_field_1.AccessMethodField("roleArn", "Insert Role ARN", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("parentSessionId", "Select Assumer Session", access_method_field_type_1.AccessMethodFieldType.list, awsAssumerSessionChoices),
                        new access_method_field_1.AccessMethodField("roleSessionName", "Role Session Name", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("profileId", "Select the Named Profile", access_method_field_type_1.AccessMethodFieldType.list, awsNamedProfileChoices),
                    ], true),
                    new access_method_1.AccessMethod(session_type_1.SessionType.awsSsoRole, "AWS Single Sign-On", [], false),
                ],
            ],
            [
                cloud_provider_type_1.CloudProviderType.azure,
                [
                    new access_method_1.AccessMethod(session_type_1.SessionType.azure, "Azure", [
                        new access_method_field_1.AccessMethodField("sessionName", "Insert session alias", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("region", "Select Location", access_method_field_type_1.AccessMethodFieldType.list, azureLocationChoices),
                        new access_method_field_1.AccessMethodField("subscriptionId", "Insert Subscription Id", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("tenantId", "Insert Tenant Id", access_method_field_type_1.AccessMethodFieldType.input),
                    ], true),
                ],
            ],
            [
                cloud_provider_type_1.CloudProviderType.localstack,
                [
                    new access_method_1.AccessMethod(session_type_1.SessionType.localstack, "LocalStack", [
                        new access_method_field_1.AccessMethodField("sessionName", "Insert session alias", access_method_field_type_1.AccessMethodFieldType.input),
                        new access_method_field_1.AccessMethodField("region", "Select Location", access_method_field_type_1.AccessMethodFieldType.list, awsRegionChoices),
                        new access_method_field_1.AccessMethodField("profileId", "Select the Named Profile", access_method_field_type_1.AccessMethodFieldType.list, awsNamedProfileChoices),
                    ], true),
                ],
            ],
        ]);
    }
    get regionMap() {
        const awsRegionChoices = this.getAwsRegionChoices();
        const azureLocationChoices = this.getAzureLocationChoices();
        return new Map([
            [session_type_1.SessionType.aws, awsRegionChoices],
            [session_type_1.SessionType.awsIamUser, awsRegionChoices],
            [session_type_1.SessionType.awsSsoRole, awsRegionChoices],
            [session_type_1.SessionType.awsIamRoleFederated, awsRegionChoices],
            [session_type_1.SessionType.awsIamRoleChained, awsRegionChoices],
            [session_type_1.SessionType.azure, azureLocationChoices],
        ]);
    }
    getAzureLocationChoices() {
        return this.azureCoreService.getLocations().map((location) => new field_choice_1.FieldChoice(location.location, location.location));
    }
    getAwsRegionChoices() {
        return this.awsCoreService.getRegions().map((value) => new field_choice_1.FieldChoice(value.region, value.region));
    }
    getAwsAssumerSessionChoices() {
        return this.repository
            .getSessions()
            .filter((session) => aws_assumer_session_types_1.AWS_ASSUMER_SESSION_TYPES.includes(session.type))
            .map((session) => new field_choice_1.FieldChoice(session.sessionName, session.sessionId));
    }
    getAwsNamedProfileChoices() {
        return this.namedProfilesService.getNamedProfiles().map((profile) => new field_choice_1.FieldChoice(profile.name, profile.id));
    }
    getIdpUrls() {
        const idpUrlsFieldChoices = this.idpUrlService.getIdpUrls().map((idpUrl) => new field_choice_1.FieldChoice(idpUrl.url, idpUrl.id));
        return idpUrlsFieldChoices.concat(new field_choice_1.FieldChoice("Create new", exports.createNewIdpUrlFieldChoice));
    }
}
exports.CloudProviderService = CloudProviderService;
//# sourceMappingURL=cloud-provider-service.js.map