import { INativeService } from "../interfaces/i-native-service";
import { Repository } from "./repository";
import { LogService } from "./log-service";
export declare class ExecuteService {
    private nativeService;
    private repository;
    private logService;
    constructor(nativeService: INativeService, repository: Repository, logService: LogService);
    getQuote(): string;
    /**
     * Execute a command: if the command contains sudo the system launch it with sudo prompt.
     * Note: with the current version of Electron the sandbox option for Chromium don't allow for sudo prompt on Ubuntu machines 16+
     * Remove the note whenever a fix is found.
     *
     * @param command - the command to launch
     * @param env - environment
     * @param maskOutputLog - to mask logging of secret outputs
     * @returns an {Promise<string>} stdout or stderr
     */
    execute(command: string, env?: any, maskOutputLog?: boolean): Promise<string>;
    /**
     * Open a command terminal and launch a generic command
     *
     * @param command - the command to launch in terminal
     * @param env - optional the environment object we can set to pass environment variables
     * @param macOsTerminalType - optional to override terminal type selection on macOS
     * @returns an {Promise<string>} stdout or stderr
     */
    openTerminal(command: string, env?: any, macOsTerminalType?: string): Promise<string>;
    openTerminalFromPlugin(command: string, env?: any): Promise<string>;
    private exec;
}
