import { INativeService } from "../interfaces/i-native-service";
export declare class FileService {
    private nativeService;
    private readSubscription;
    private _aesKey;
    constructor(nativeService: INativeService);
    get aesKey(): string;
    set aesKey(value: string);
    /**
     * Get the home directory
     *
     * @returns - {string} - path of the home directory
     */
    homeDir(): string;
    /**
     * Check if a file or directory exists by passing a path
     *
     * @returns - {boolean} - exists or not
     * @param path - the path of the directory
     */
    existsSync(path: string): boolean;
    renameSync(oldPath: string, newPath: string): void;
    /**
     * Get directory name
     *
     * @returns - {string} - the directory name
     * @param path - the directory path
     */
    dirname(path: string): string;
    /**
     * Copy the directory
     *
     * @param source - source directory
     * @param target - target directory
     */
    copyDir(source: string, target: string): void;
    /**
     * Read file sync
     *
     * @returns - {string} - return the file directly as string
     * @param filePath - Path to read the file
     */
    readFileSync(filePath: string): string;
    /**
     * Read the directories in a recursive manner
     *
     * @returns - {any} - data
     * @param source - source of the directory
     */
    getSubDirs(source: string): string[];
    /**
     * Creates a new directory
     *
     * @param path - the new directory path
     * @param options - some options if needed - optional
     */
    newDir(path: string, options: {
        recursive: boolean;
    }): void;
    /**
     * Write a generic file in a synchronous way
     *
     * @returns - {any}
     * @param filePath - the filepath to write to
     * @param content - the content to write
     */
    writeFileSync(filePath: string, content: string): any;
    writeFileSyncWithOptions(filePath: string, content: string, options: any): any;
    /**
     * Remove a file in a synchronous way
     *
     * @returns - {void}
     * @param filePath - the filepath to remove
     */
    removeFileSync(filePath: string): void;
    /**
     * Write the ini file passing each key to the writer avoinding the empty key/value couple
     *
     * @returns - {any} - the result of the operation
     * @param filePath - the filepath to write to
     * @param content - the content to write
     */
    iniWriteSync(filePath: string, content: any): any;
    replaceWriteSync(filePath: string, content: any): any;
    /**
     * Parse the ini file in a synch way
     *
     * @returns - {any} - returns the parsed string
     * @param filePath - the filepath to read from
     */
    iniParseSync(filePath: string): any;
    /**
     * Encrypt Text
     */
    encryptText(text: string): string;
    /**
     * Decrypt Text
     */
    decryptText(text: string): string;
}
