"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IdpUrlsService = void 0;
const uuid = __importStar(require("uuid"));
const idp_url_1 = require("../models/idp-url");
class IdpUrlsService {
    constructor(sessionFactory, repository) {
        this.sessionFactory = sessionFactory;
        this.repository = repository;
    }
    getIdpUrls() {
        return this.repository.getIdpUrls();
    }
    getIdpUrl(id) {
        const idpUrl = this.repository.getIdpUrl(id);
        if (idpUrl) {
            return new idp_url_1.IdpUrl(id, idpUrl);
        }
        else
            return null;
    }
    /**
     * Get or create the AWS IdPUrl ID from the unique name
     *
     * @param url
     * @return id the IdP URL id if the given URL if the idpUrl exists, otherwise creates a new IdPUrl and returns its id
     */
    getIdpUrlIdByUrl(url) {
        var _a;
        const idpUrlId = (_a = this.getIdpUrls().find((idpUrl) => idpUrl.url === url)) === null || _a === void 0 ? void 0 : _a.id;
        if (!idpUrlId) {
            return this.createIdpUrl(url).id;
        }
        return idpUrlId;
    }
    createIdpUrl(idpUrl) {
        const newIdpUrl = new idp_url_1.IdpUrl(this.getNewId(), idpUrl.trim());
        this.repository.addIdpUrl(newIdpUrl);
        return newIdpUrl;
    }
    editIdpUrl(id, newIdpUrl) {
        this.repository.updateIdpUrl(id, newIdpUrl.trim());
    }
    async deleteIdpUrl(id) {
        for (const sessionToDelete of this.getDependantSessions(id, false)) {
            const sessionService = this.sessionFactory.getSessionService(sessionToDelete.type);
            await sessionService.delete(sessionToDelete.sessionId);
        }
        this.repository.removeIdpUrl(id);
    }
    validateIdpUrl(url) {
        const trimmedUrl = url.trim();
        if (trimmedUrl.length === 0) {
            return "Empty IdP URL";
        }
        const isUrl = trimmedUrl.startsWith("http://") || trimmedUrl.startsWith("https://");
        if (!isUrl) {
            return "IdP URL is not a valid URL";
        }
        const existingUrls = this.getIdpUrls().map((idpUrl) => idpUrl.url);
        if (existingUrls.includes(trimmedUrl)) {
            return "IdP URL already exists";
        }
        return true;
    }
    getDependantSessions(idpUrlId, includingChained = true) {
        const dependantSessions = this.repository.getSessions().filter((session) => session.idpUrlId === idpUrlId);
        return includingChained
            ? dependantSessions.flatMap((parentSession) => [parentSession, ...this.repository.listIamRoleChained(parentSession)])
            : dependantSessions;
    }
    mergeIdpUrl(url) {
        const actualIdpUrl = this.repository.getIdpUrls().find((idpUrl) => idpUrl.url === url);
        if (actualIdpUrl) {
            return actualIdpUrl;
        }
        else {
            return this.createIdpUrl(url);
        }
    }
    getNewId() {
        return uuid.v4();
    }
}
exports.IdpUrlsService = IdpUrlsService;
//# sourceMappingURL=idp-urls-service.js.map