"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntegrationFactory = void 0;
const integration_type_1 = require("../models/integration-type");
class IntegrationFactory {
    constructor(awsSsoIntegrationService, azureIntegrationService) {
        this.awsSsoIntegrationService = awsSsoIntegrationService;
        this.azureIntegrationService = azureIntegrationService;
    }
    getIntegrationService(integrationType) {
        switch (integrationType) {
            case integration_type_1.IntegrationType.awsSso:
                return this.awsSsoIntegrationService;
            case integration_type_1.IntegrationType.azure:
                return this.azureIntegrationService;
        }
    }
    async create(integrationType, creationParams) {
        const integrationService = this.getIntegrationService(integrationType);
        await integrationService.createIntegration(creationParams);
    }
    async update(integrationId, updateParams) {
        var _a;
        const integrationType = (_a = this.getIntegrationById(integrationId)) === null || _a === void 0 ? void 0 : _a.type;
        if (integrationType === integration_type_1.IntegrationType.azure) {
            const currentIntegration = this.azureIntegrationService.getIntegration(integrationId);
            if (currentIntegration.tenantId !== updateParams.tenantId) {
                await this.azureIntegrationService.logout(integrationId);
            }
        }
        const integrationService = this.getIntegrationService(integrationType);
        await integrationService.updateIntegration(integrationId, updateParams);
    }
    async delete(integrationId) {
        var _a;
        const integrationType = (_a = this.getIntegrationById(integrationId)) === null || _a === void 0 ? void 0 : _a.type;
        const integrationService = this.getIntegrationService(integrationType);
        await integrationService.deleteIntegration(integrationId);
    }
    async syncSessions(integrationId) {
        var _a;
        const integrationType = (_a = this.getIntegrationById(integrationId)) === null || _a === void 0 ? void 0 : _a.type;
        const integrationService = this.getIntegrationService(integrationType);
        return await integrationService.syncSessions(integrationId);
    }
    async logout(integrationId) {
        var _a;
        const integrationType = (_a = this.getIntegrationById(integrationId)) === null || _a === void 0 ? void 0 : _a.type;
        const integrationService = this.getIntegrationService(integrationType);
        await integrationService.logout(integrationId);
    }
    getRemainingHours(integration) {
        var _a;
        const integrationType = (_a = this.getIntegrationById(integration.id)) === null || _a === void 0 ? void 0 : _a.type;
        const integrationService = this.getIntegrationService(integrationType);
        if (integrationType && integrationService) {
            return integrationService.remainingHours(integration);
        }
        else {
            return "";
        }
    }
    async setOnline(integration) {
        var _a;
        const integrationType = (_a = this.getIntegrationById(integration.id)) === null || _a === void 0 ? void 0 : _a.type;
        const integrationService = this.getIntegrationService(integrationType);
        await integrationService.setOnline(integration);
    }
    getIntegrations() {
        return [...this.awsSsoIntegrationService.getIntegrations(), ...this.azureIntegrationService.getIntegrations()];
    }
    getIntegrationById(integrationId) {
        return this.getIntegrations().find((integration) => integration.id === integrationId);
    }
}
exports.IntegrationFactory = IntegrationFactory;
//# sourceMappingURL=integration-factory.js.map