import { Repository } from "../repository";
import { AwsSsoRoleService, SsoRoleSession } from "../session/aws/aws-sso-role-service";
import { AwsSsoIntegration } from "../../models/aws/aws-sso-integration";
import { INativeService } from "../../interfaces/i-native-service";
import { AwsSsoOidcService } from "../aws-sso-oidc.service";
import { GetRoleCredentialsResponse } from "@aws-sdk/client-sso";
import { AwsSsoRoleSession } from "../../models/aws/aws-sso-role-session";
import { IBehaviouralNotifier } from "../../interfaces/i-behavioural-notifier";
import { AwsSsoIntegrationTokenInfo } from "../../models/aws/aws-sso-integration-token-info";
import { SessionFactory } from "../session-factory";
import { IIntegrationService } from "../../interfaces/i-integration-service";
import { AwsSsoIntegrationCreationParams } from "../../models/aws/aws-sso-integration-creation-params";
import { IKeychainService } from "../../interfaces/i-keychain-service";
export interface SsoSessionsDiff {
    sessionsToDelete: AwsSsoRoleSession[];
    sessionsToAdd: SsoRoleSession[];
}
export declare class AwsSsoIntegrationService implements IIntegrationService {
    repository: Repository;
    keyChainService: IKeychainService;
    behaviouralNotifier: IBehaviouralNotifier;
    nativeService: INativeService;
    sessionFactory: SessionFactory;
    private awsSsoOidcService;
    private awsSsoRoleService;
    private ssoPortal;
    private listAccountRolesCall;
    constructor(repository: Repository, keyChainService: IKeychainService, behaviouralNotifier: IBehaviouralNotifier, nativeService: INativeService, sessionFactory: SessionFactory, awsSsoOidcService: AwsSsoOidcService, awsSsoRoleService: AwsSsoRoleService);
    static validateAlias(alias: string): boolean | string;
    static validatePortalUrl(portalUrl: string): boolean | string;
    createIntegration(creationParams: AwsSsoIntegrationCreationParams, _integrationId?: string): Promise<void>;
    updateIntegration(id: string, updateParams: AwsSsoIntegrationCreationParams): void;
    getIntegration(id: string): AwsSsoIntegration;
    getIntegrations(): AwsSsoIntegration[];
    getOnlineIntegrations(): AwsSsoIntegration[];
    getOfflineIntegrations(): AwsSsoIntegration[];
    setOnline(integration: AwsSsoIntegration, forcedState?: boolean): Promise<void>;
    remainingHours(integration: AwsSsoIntegration): string;
    loginAndGetSessionsDiff(integrationId: string, onUserAuthenticated?: () => void): Promise<SsoSessionsDiff>;
    syncSessions(integrationId: string, onUserAuthenticated?: () => void): Promise<any>;
    logout(integrationId: string): Promise<void>;
    getAccessToken(integrationId: string, region: string, portalUrl: string): Promise<string>;
    getRoleCredentials(accessToken: string, region: string, roleArn: string): Promise<GetRoleCredentialsResponse>;
    getAwsSsoIntegrationTokenInfo(awsSsoIntegrationId: string): Promise<AwsSsoIntegrationTokenInfo>;
    isAwsSsoAccessTokenExpired(awsSsoIntegrationId: string): Promise<boolean>;
    deleteIntegration(integrationId: string): Promise<void>;
    private getSessions;
    private configureAwsSso;
    private getAccessTokenFromKeychain;
    private getIntegrationAccessTokenKey;
    private login;
    private setupSsoPortalClient;
    private listAccounts;
    private recursiveListAccounts;
    private getSessionsFromAccount;
    private recursiveListRoles;
    private findOldSession;
    private deleteDependentSessions;
    private getProtocol;
    private getDate;
}
