import { IBehaviouralNotifier } from "../../interfaces/i-behavioural-notifier";
import { IIntegrationService } from "../../interfaces/i-integration-service";
import { INativeService } from "../../interfaces/i-native-service";
import { Repository } from "../repository";
import { SessionFactory } from "../session-factory";
import { Integration } from "../../models/integration";
import { AzureIntegration } from "../../models/azure/azure-integration";
import { ExecuteService } from "../execute-service";
import { AzurePersistenceService } from "../azure-persistence-service";
import { AzureIntegrationCreationParams } from "../../models/azure/azure-integration-creation-params";
import { AzureSessionService } from "../session/azure/azure-session-service";
export declare class AzureIntegrationService implements IIntegrationService {
    repository: Repository;
    behaviouralNotifier: IBehaviouralNotifier;
    nativeService: INativeService;
    sessionFactory: SessionFactory;
    executeService: ExecuteService;
    azureSessionService: AzureSessionService;
    azurePersistenceService: AzurePersistenceService;
    constructor(repository: Repository, behaviouralNotifier: IBehaviouralNotifier, nativeService: INativeService, sessionFactory: SessionFactory, executeService: ExecuteService, azureSessionService: AzureSessionService, azurePersistenceService: AzurePersistenceService);
    static validateAlias(alias: string): boolean | string;
    static validateTenantId(tenantId: string): boolean | string;
    checkCliVersion(): Promise<void>;
    createIntegration(creationParams: AzureIntegrationCreationParams, _integrationId?: string): Promise<void>;
    updateIntegration(id: string, updateParams: AzureIntegrationCreationParams): void;
    deleteIntegration(id: string): Promise<void>;
    getIntegration(integrationId: string): AzureIntegration;
    getIntegrations(): AzureIntegration[];
    setOnline(integration: AzureIntegration, forcedState?: boolean): Promise<void>;
    logout(integrationId: string): Promise<void>;
    remainingHours(_integration: Integration): string;
    syncSessions(integrationId: string): Promise<any>;
    private notifyIntegrationChanges;
    private moveSecretsToKeychain;
    private deleteDependentSessions;
}
