"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeychainService = void 0;
class KeychainService {
    constructor(nativeService) {
        this.nativeService = nativeService;
    }
    /**
     * Save your secret in the keychain
     *
     * @param service - environment.appName
     * @param account - unique identifier
     * @param password - secret - not null
     */
    async saveSecret(service, account, password) {
        return await this.nativeService.keytar.setPassword(service, account, password !== null && password !== void 0 ? password : "<EMPTY>");
    }
    /**
     * Retrieve a Secret from the keychain
     *
     * @param service - environment.appName
     * @param account - unique identifier
     * @returns the secret
     */
    async getSecret(service, account) {
        return await this.nativeService.keytar.getPassword(service, account);
    }
    /**
     * Delete a secret from the keychain
     *
     * @param service - environment.appName
     * @param account - unique identifier
     */
    async deleteSecret(service, account) {
        return await this.nativeService.keytar.deleteSecret(service, account);
    }
}
exports.KeychainService = KeychainService;
//# sourceMappingURL=keychain-service.js.map