"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogService = exports.LoggedException = exports.LoggedEntry = exports.LogLevel = void 0;
/* istanbul ignore next */
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["success"] = 0] = "success";
    LogLevel[LogLevel["info"] = 1] = "info";
    LogLevel[LogLevel["warn"] = 2] = "warn";
    LogLevel[LogLevel["error"] = 3] = "error";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
class LoggedEntry extends Error {
    constructor(message, context, level, display = false, customStack) {
        super(message);
        this.context = context;
        this.level = level;
        this.display = display;
        this.customStack = customStack;
    }
}
exports.LoggedEntry = LoggedEntry;
class LoggedException extends LoggedEntry {
    constructor(message, context, level, display = true, customStack) {
        super(message, context, level, display, customStack);
        this.context = context;
        this.level = level;
        this.display = display;
        this.customStack = customStack;
    }
}
exports.LoggedException = LoggedException;
class LogService {
    constructor(logger) {
        this.logger = logger;
    }
    log(loggedEntry) {
        var _a;
        const contextPart = loggedEntry.context ? [`[${loggedEntry.context.constructor["name"]}]`] : [];
        if (loggedEntry.level === LogLevel.error)
            this.logger.log([...contextPart, (_a = loggedEntry.customStack) !== null && _a !== void 0 ? _a : loggedEntry.stack].join(" "), loggedEntry.level);
        else
            this.logger.log(loggedEntry.message, loggedEntry.level);
        if (loggedEntry.display) {
            this.logger.show(loggedEntry.message, loggedEntry.level);
        }
    }
    getCoreVersion() {
        return require("../../package.json").version;
    }
}
exports.LogService = LogService;
//# sourceMappingURL=log-service.js.map