"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.NamedProfilesService = void 0;
const uuid = __importStar(require("uuid"));
const constants_1 = require("../models/constants");
const aws_named_profile_1 = require("../models/aws/aws-named-profile");
const session_status_1 = require("../models/session-status");
const aws_session_service_1 = require("./session/aws/aws-session-service");
class NamedProfilesService {
    constructor(sessionFactory, repository, behaviouralSubjectService) {
        this.sessionFactory = sessionFactory;
        this.repository = repository;
        this.behaviouralSubjectService = behaviouralSubjectService;
    }
    getNamedProfiles(excludingDefault = false) {
        const excludedProfileId = excludingDefault ? this.repository.getDefaultProfileId() : null;
        return this.repository.getProfiles().filter((profile) => profile.id !== excludedProfileId);
    }
    getProfileName(profileId) {
        return this.repository.getProfileName(profileId);
    }
    getDefaultProfileId() {
        return this.repository.getDefaultProfileId();
    }
    getNamedProfilesMap() {
        return new Map(this.getNamedProfiles().map((profile) => [profile.id, profile]));
    }
    /**
     * Get or create the AWS named profile ID from the unique name
     *
     * @param profileName
     * @return id the profile id if the named profile exists, otherwise creates a new profile and returns its id
     */
    getProfileIdByName(profileName) {
        var _a;
        const profileId = (_a = this.getNamedProfiles().find((profile) => profile.name === profileName)) === null || _a === void 0 ? void 0 : _a.id;
        if (!profileId) {
            return this.createNamedProfile(profileName).id;
        }
        return profileId;
    }
    getSessionsWithNamedProfile(id) {
        return this.repository.getSessions().filter((session) => session.profileId === id);
    }
    createNamedProfile(name) {
        const namedProfile = new aws_named_profile_1.AwsNamedProfile(this.getNewId(), name.trim());
        this.repository.addProfile(namedProfile);
        return namedProfile;
    }
    mergeProfileName(name) {
        const actualNamedProfile = this.repository.getProfiles().find((profile) => profile.name === name);
        if (actualNamedProfile) {
            return actualNamedProfile;
        }
        else {
            return this.createNamedProfile(name);
        }
    }
    async editNamedProfile(id, newName) {
        const activeSessions = this.getSessionsWithNamedProfile(id).filter((session) => session.status === session_status_1.SessionStatus.active);
        for (const session of activeSessions) {
            await this.sessionFactory.getSessionService(session.type).stop(session.sessionId);
        }
        this.repository.updateProfile(id, newName.trim());
        for (const session of activeSessions) {
            await this.sessionFactory.getSessionService(session.type).start(session.sessionId);
        }
    }
    async deleteNamedProfile(id) {
        const sessions = this.getSessionsWithNamedProfile(id);
        const defaultNamedProfileId = this.repository.getDefaultProfileId();
        for (const session of sessions) {
            const sessionService = this.sessionFactory.getSessionService(session.type);
            const wasActive = session.status === session_status_1.SessionStatus.active;
            if (wasActive) {
                await sessionService.stop(session.sessionId);
            }
            session.profileId = defaultNamedProfileId;
            this.repository.updateSession(session.sessionId, session);
            this.behaviouralSubjectService.setSessions(this.repository.getSessions());
            if (wasActive) {
                await sessionService.start(session.sessionId);
            }
        }
        this.repository.removeProfile(id);
    }
    async changeNamedProfile(session, newNamedProfileId) {
        const sessionService = this.sessionFactory.getSessionService(session.type);
        if (sessionService instanceof aws_session_service_1.AwsSessionService) {
            const wasActive = session.status === session_status_1.SessionStatus.active;
            if (wasActive) {
                await sessionService.stop(session.sessionId);
            }
            session.profileId = newNamedProfileId;
            this.repository.updateSession(session.sessionId, session);
            this.behaviouralSubjectService.setSessions(this.repository.getSessions());
            if (wasActive) {
                await sessionService.start(session.sessionId);
            }
        }
    }
    getNewId() {
        return uuid.v4();
    }
    validateNewProfileName(name) {
        const trimmedName = name.trim();
        if (trimmedName.length === 0) {
            return "Empty profile name";
        }
        if (trimmedName === constants_1.constants.defaultAwsProfileName) {
            return '"default" is not a valid profile name';
        }
        const namedProfilesNames = this.getNamedProfiles().map((namedProfile) => namedProfile.name);
        if (namedProfilesNames.includes(trimmedName)) {
            return "Profile already exists";
        }
        return true;
    }
}
exports.NamedProfilesService = NamedProfilesService;
//# sourceMappingURL=named-profiles-service.js.map