"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoteProceduresClient = void 0;
const constants_1 = require("../models/constants");
const remote_procedures_server_1 = require("./remote-procedures-server");
const connectionError = "unable to connect with desktop app";
class RemoteProceduresClient {
    constructor(nativeService, serverId = constants_1.constants.ipcServerId) {
        this.nativeService = nativeService;
        this.serverId = serverId;
    }
    async isDesktopAppRunning() {
        return this.remoteProcedureCall({ method: "isDesktopAppRunning", params: {} }, (data, resolve, _) => resolve(data.result), (resolve, _) => resolve(false));
    }
    async needAuthentication(idpUrl) {
        return this.remoteProcedureCall({ method: "needAuthentication", params: { idpUrl } }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError));
    }
    async needMfa(sessionName) {
        return this.remoteProcedureCall({ method: "needMFA", params: { sessionName } }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError));
    }
    async awsSignIn(idpUrl, needToAuthenticate) {
        return this.remoteProcedureCall({ method: "awsSignIn", params: { idpUrl, needToAuthenticate } }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError));
    }
    async openVerificationWindow(registerClientResponse, startDeviceAuthorizationResponse, windowModality, onWindowClose) {
        return this.remoteProcedureCall({
            method: "openVerificationWindow",
            params: { registerClientResponse, startDeviceAuthorizationResponse, windowModality },
        }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError), (data, _, __) => (data.callbackId === "onWindowClose" ? onWindowClose() : null));
    }
    async refreshSessions() {
        return this.remoteProcedureCall({ method: "refreshSessions", params: {} }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError));
    }
    async refreshIntegrations() {
        return this.remoteProcedureCall({ method: "refreshIntegrations", params: {} }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError));
    }
    async msalProtectData(dataToEncrypt, optionalEntropy, scope) {
        return this.remoteProcedureCall({
            method: "msalProtectData",
            params: {
                dataToEncrypt: (0, remote_procedures_server_1.uInt8ArrayToArray)(dataToEncrypt),
                optionalEntropy: (0, remote_procedures_server_1.uInt8ArrayToArray)(optionalEntropy),
                scope,
            },
        }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve((0, remote_procedures_server_1.arrayToUInt8Array)(data.result))), (_, reject) => reject(connectionError));
    }
    async msalUnprotectData(encryptedData, optionalEntropy, scope) {
        return this.remoteProcedureCall({
            method: "msalUnprotectData",
            params: {
                encryptedData: (0, remote_procedures_server_1.uInt8ArrayToArray)(encryptedData),
                optionalEntropy: (0, remote_procedures_server_1.uInt8ArrayToArray)(optionalEntropy),
                scope,
            },
        }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve((0, remote_procedures_server_1.uInt8ArrayToArray)(data.result))), (_, reject) => reject(connectionError));
    }
    async keychainSaveSecret(service, account, password) {
        return this.remoteProcedureCall({
            method: "keychainSaveSecret",
            params: { service, account, password },
        }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError));
    }
    async keychainGetSecret(service, account) {
        return this.remoteProcedureCall({
            method: "keychainGetSecret",
            params: { service, account },
        }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError));
    }
    async keychainDeleteSecret(service, account) {
        return this.remoteProcedureCall({
            method: "keychainDeleteSecret",
            params: { service, account },
        }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError));
    }
    async refreshWorkspaceState() {
        return this.remoteProcedureCall({ method: "refreshWorkspaceState", params: {} }, (data, resolve, reject) => (data.error ? reject(data.error) : resolve(data.result)), (_, reject) => reject(connectionError));
    }
    async remoteProcedureCall(rpcRequest, onReturn, onDisconnect, onCallback) {
        const ipc = this.nativeService.nodeIpc;
        ipc.config.id = "leapp_cli";
        ipc.config.maxRetries = 2;
        ipc.config.silent = true;
        ipc.config.encoding = "utf8";
        return new Promise((resolve, reject) => {
            ipc.connectTo(this.serverId, () => {
                const desktopAppServer = ipc.of[this.serverId];
                desktopAppServer.on("connect", () => {
                    desktopAppServer.emit("message", rpcRequest);
                });
                desktopAppServer.on("disconnect", () => {
                    onDisconnect(resolve, reject);
                });
                desktopAppServer.on("message", (data) => {
                    if (data.callbackId && onCallback) {
                        onCallback(data, resolve, reject);
                    }
                    else {
                        onReturn(data, resolve, reject);
                        ipc.disconnect(this.serverId);
                    }
                });
            });
        });
    }
}
exports.RemoteProceduresClient = RemoteProceduresClient;
//# sourceMappingURL=remote-procedures-client.js.map