/// <reference types="node" />
import { INativeService } from "../interfaces/i-native-service";
import { IAwsSsoOidcVerificationWindowService } from "../interfaces/i-aws-sso-oidc-verification-window-service";
import { IAwsSamlAuthenticationService } from "../interfaces/i-aws-saml-authentication-service";
import { Repository } from "./repository";
import { BehaviouralSubjectService } from "./behavioural-subject-service";
import { IMfaCodePrompter } from "../interfaces/i-mfa-code-prompter";
import { IntegrationFactory } from "./integration-factory";
import { IKeychainService } from "../interfaces/i-keychain-service";
import { WorkspaceService } from "./workspace-service";
import { ITeamService } from "../interfaces/i-team-service";
export declare const uInt8ArrayToArray: (uint8array: Uint8Array) => Array<number>;
export declare const arrayToUInt8Array: (serializedArray: Array<number>) => Buffer;
export interface RpcResponse {
    result?: any;
    error?: any;
    callbackId?: string;
}
export interface RpcRequest {
    method: string;
    params: any;
}
export declare class RemoteProceduresServer {
    private keychainService;
    private nativeService;
    private verificationWindowService;
    private awsAuthenticationService;
    private integrationFactory;
    private mfaCodePrompter;
    private repository;
    private behaviouralSubjectService;
    private teamService;
    private workspaceService;
    private uiSafeFn;
    private serverId;
    private rpcMethods;
    constructor(keychainService: IKeychainService, nativeService: INativeService, verificationWindowService: IAwsSsoOidcVerificationWindowService, awsAuthenticationService: IAwsSamlAuthenticationService, integrationFactory: IntegrationFactory, mfaCodePrompter: IMfaCodePrompter, repository: Repository, behaviouralSubjectService: BehaviouralSubjectService, teamService: ITeamService, workspaceService: WorkspaceService, uiSafeFn: (uiSafeBlock: () => void) => void, serverId?: string);
    startServer(): void;
    stopServer(): void;
    private isDesktopAppRunning;
    private needMfa;
    private needAuthentication;
    private awsSignIn;
    private openVerificationWindow;
    private refreshIntegrations;
    private refreshSessions;
    private msalProtectData;
    private msalUnprotectData;
    private keychainSaveSecret;
    private keychainGetSecret;
    private keychainDeleteSecret;
    private refreshWorkspaceState;
}
