import { INativeService } from "../interfaces/i-native-service";
import { AwsNamedProfile } from "../models/aws/aws-named-profile";
import { AwsSsoIntegration } from "../models/aws/aws-sso-integration";
import Segment from "../models/segment";
import { Session } from "../models/session";
import { Workspace } from "../models/workspace";
import { FileService } from "./file-service";
import { IdpUrl } from "../models/idp-url";
import Folder from "../models/folder";
import { AzureIntegration } from "../models/azure/azure-integration";
import PluginStatus from "../models/plugin-status";
import { WorkspaceConsistencyService } from "./workspace-consistency-service";
import { LeappNotification } from "../models/notification";
import { GlobalSettings } from "../interfaces/i-global-settings";
export declare class Repository {
    private nativeService;
    private fileService;
    private workspaceConsistencyService;
    private _workspace;
    private _workspaceFileName;
    constructor(nativeService: INativeService, fileService: FileService, workspaceConsistencyService: WorkspaceConsistencyService);
    get workspace(): Workspace;
    set workspace(value: Workspace);
    get workspaceFileName(): string;
    set workspaceFileName(value: string);
    reloadWorkspace(): void;
    getWorkspace(): Workspace;
    createWorkspace(): void;
    removeWorkspace(): void;
    persistWorkspace(workspace: Workspace): void;
    getSessions(): Session[];
    getSessionById(sessionId: string): Session;
    addSession(session: Session): void;
    updateSession(sessionId: string, session: Session): void;
    updateSessions(sessions: Session[]): void;
    deleteSession(sessionId: string): void;
    listPending(): Session[];
    listActive(): Session[];
    listActiveAndPending(): Session[];
    listAwsSsoRoles(): Session[];
    listAssumable(): Session[];
    listIamRoleChained(parentSession?: Session): Session[];
    createPluginStatus(pluginId: string): void;
    getPluginStatus(pluginId: string): PluginStatus;
    setPluginStatus(pluginId: string, newStatus: PluginStatus): void;
    getDefaultRegion(): string;
    getDefaultLocation(): string;
    updateDefaultRegion(defaultRegion: string): void;
    updateDefaultLocation(defaultLocation: string): void;
    getIdpUrl(idpUrlId: string): string | null;
    getIdpUrls(): IdpUrl[];
    addIdpUrl(idpUrl: IdpUrl): void;
    updateIdpUrl(id: string, url: string): void;
    removeIdpUrl(id: string): void;
    getProfiles(): AwsNamedProfile[];
    getProfileName(profileId: string): string;
    doesProfileExist(profileId: string): boolean;
    getDefaultProfileId(): string;
    addProfile(profile: AwsNamedProfile): void;
    updateProfile(profileId: string, newName: string): void;
    removeProfile(profileId: string): void;
    listAwsSsoIntegrations(): AwsSsoIntegration[];
    getAwsSsoIntegration(id: string | number): AwsSsoIntegration;
    getAwsSsoIntegrationSessions(id: string | number): Session[];
    addAwsSsoIntegration(portalUrl: string, alias: string, region: string, browserOpening: string): void;
    updateAwsSsoIntegration(id: string, alias: string, region: string, portalUrl: string, browserOpening: string, isOnline: boolean, expirationTime?: string): void;
    unsetAwsSsoIntegrationExpiration(id: string): void;
    deleteAwsSsoIntegration(id: string): void;
    addAzureIntegration(alias: string, tenantId: string, region: string): void;
    updateAzureIntegration(id: string, alias: string, tenantId: string, region: string, isOnline: boolean, tokenExpiration?: string): void;
    deleteAzureIntegration(id: string): void;
    getAzureIntegration(id: string | number): AzureIntegration;
    listAzureIntegrations(): AzureIntegration[];
    getProxyConfiguration(): any;
    updateProxyConfiguration(proxyConfiguration: {
        proxyProtocol: string;
        proxyUrl?: string;
        proxyPort: string;
        username?: string;
        password?: string;
    }): void;
    getSegments(): Segment[];
    getSegment(segmentName: string): Segment;
    setSegments(segments: Segment[]): void;
    removeSegment(segment: Segment): void;
    getFolders(): Folder[];
    setFolders(folders: Folder[]): void;
    updateMacOsTerminal(macOsTerminal: string): void;
    updateColorTheme(colorTheme: string): void;
    getColorTheme(): string;
    writeFile(data: string): void;
    get globalSettings(): GlobalSettings;
    set globalSettings(globalSettingsInput: GlobalSettings);
    /**
     * Get Notifications
     * Get all the notifications that the user has received
     *
     * @return LeappNotification[] - the notification array
     */
    getNotifications(): LeappNotification[];
    /**
     * Set Notifications
     * Set the array of new notifications , it can be used to re-update the current array, i.e. after a read message
     *
     * @param notifications - the notification array
     */
    setNotifications(notifications: LeappNotification[]): void;
    private getSessionsOrDefault;
}
