"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RetroCompatibilityService = void 0;
const class_transformer_1 = require("class-transformer");
const workspace_1 = require("../models/workspace");
const constants_1 = require("../models/constants");
const uuid = __importStar(require("uuid"));
const session_type_1 = require("../models/session-type");
const aws_sso_integration_1 = require("../models/aws/aws-sso-integration");
const azure_integration_1 = require("../models/azure/azure-integration");
const integration_type_1 = require("../models/integration-type");
class RetroCompatibilityService {
    constructor(fileService, keyChainService, repository, behaviouralSubjectService) {
        this.fileService = fileService;
        this.keyChainService = keyChainService;
        this.repository = repository;
        this.behaviouralSubjectService = behaviouralSubjectService;
    }
    /* TODO: refactor and call this method only inside WorkspaceConsistencyService's getWorkspace: in this way
        we don't need to use fileService and behaviouralSubjectService anymore because the conversion is
        done BEFORE workspace is read and returned to the rest of the app and so it can be done "in memory"
        without persistence and without notifying anything!
     */
    async applyWorkspaceMigrations() {
        if (this.fileService.existsSync(this.lockFilePath)) {
            await this.migration0();
            this.migration1();
            this.migration2();
            this.migration3();
            this.migration4();
            this.migration5();
            this.migration6();
            this.migration7();
            // When adding new migrations remember to increase constants.workspaceLastVersion
        }
    }
    isIntegrationPatchNecessary() {
        const workspaceParsed = this.getWorkspace();
        // check for new integration array if present or not
        return (!workspaceParsed._awsSsoIntegrations ||
            (workspaceParsed._awsSsoIntegrations.length === 0 && workspaceParsed._sessions.filter((s) => s.type === "awsSsoRole").length > 0));
    }
    async integrationTypeEnumPatch() {
        const workspace = this.getWorkspace();
        const integrations = [
            ...(workspace._awsSsoIntegrations ? workspace._awsSsoIntegrations : []),
            ...(workspace._azureIntegrations ? workspace._azureIntegrations : []),
        ];
        const awsIntegrations = [];
        const azureIntegrations = [];
        for (const integration of integrations) {
            if (integration.type === "awsSso" || !integration.type) {
                integration.type = integration_type_1.IntegrationType.awsSso;
                awsIntegrations.push(integration);
            }
            else if (integration.type === "azure") {
                integration.type = integration_type_1.IntegrationType.azure;
                azureIntegrations.push(integration);
            }
            else if (integration.type === integration_type_1.IntegrationType.awsSso) {
                awsIntegrations.push(integration);
            }
            else if (integration.type === integration_type_1.IntegrationType.azure) {
                azureIntegrations.push(integration);
            }
        }
        workspace._awsSsoIntegrations = awsIntegrations;
        workspace._azureIntegrations = azureIntegrations;
        this.reloadIntegrations(workspace);
    }
    async adaptIntegrationPatch() {
        const workspace = new workspace_1.Workspace();
        const oldWorkspace = this.getWorkspace();
        await this.adaptIntegrations(oldWorkspace, workspace);
        // Persist adapted workspace data
        this.persists(workspace);
        // Apply sessions to behaviour subject
        this.behaviouralSubjectService.sessions = workspace.sessions;
        this.repository.workspace = workspace;
        return workspace;
    }
    async adaptIntegrations(oldWorkspace, workspace) {
        if (!workspace.awsSsoIntegrations) {
            workspace.awsSsoIntegrations = [];
        }
        workspace.idpUrls = oldWorkspace._idpUrls;
        workspace.profiles = oldWorkspace._profiles;
        workspace.proxyConfiguration = oldWorkspace._proxyConfiguration;
        workspace.defaultRegion = oldWorkspace._defaultRegion;
        workspace.defaultLocation = oldWorkspace._defaultLocation;
        //await this.adaptNewSessions(oldWorkspace, workspace);
        // Get AWS SSO Configuration from both intermediate and old configs
        const awsSsoConfiguration = oldWorkspace._awsSsoConfiguration || oldWorkspace.awsSsoConfiguration;
        if (workspace.sessions.filter((sess) => sess.type === session_type_1.SessionType.awsSsoRole.toString()).length > 0) {
            if (workspace.awsSsoIntegrations.length === 0) {
                workspace.awsSsoIntegrations.push(new aws_sso_integration_1.AwsSsoIntegration(uuid.v4(), "Aws Single Sign-On", awsSsoConfiguration.portalUrl, awsSsoConfiguration.region, constants_1.constants.inApp, awsSsoConfiguration.expirationTime));
                try {
                    const accessToken = await this.keyChainService.getSecret(constants_1.constants.appName, `aws-sso-access-token`);
                    await this.keyChainService.saveSecret(constants_1.constants.appName, `aws-sso-integration-access-token-${workspace.awsSsoIntegrations[0].id}`, accessToken);
                }
                catch (_) {
                    console.log("no need to save access token");
                }
            }
            for (let i = 0; i < workspace.sessions.length; i++) {
                const session = workspace.sessions[i];
                // We have changed the enum type so we must check it manually
                if (session.type === session_type_1.SessionType.awsSsoRole.toString()) {
                    session.awsSsoConfigurationId = workspace.awsSsoIntegrations[0].id;
                    workspace.sessions[i] = session;
                }
            }
        }
    }
    get lockFilePath() {
        return this.fileService.homeDir() + "/" + constants_1.constants.lockFileDestination;
    }
    async migration0() {
        if (this.isIntegrationPatchNecessary()) {
            await this.adaptIntegrationPatch();
        }
        await this.integrationTypeEnumPatch();
    }
    checkMigration(workspace, previousVersion, currentVersion) {
        const isMigrationNeeded = workspace._workspaceVersion === previousVersion;
        if (!isMigrationNeeded) {
            return false;
        }
        workspace._workspaceVersion = currentVersion;
        return true;
    }
    migration1() {
        const workspace = this.getWorkspace();
        if (!this.checkMigration(workspace, undefined, 1)) {
            return;
        }
        const awsSsoIntegrations = workspace._awsSsoIntegrations;
        const newAwsSsoIntegrations = [];
        if (awsSsoIntegrations && awsSsoIntegrations.length > 0) {
            for (let i = 0; i < awsSsoIntegrations.length; i++) {
                let newAwsSsoIntegration;
                if (awsSsoIntegrations[i].isOnline === undefined) {
                    newAwsSsoIntegration = new aws_sso_integration_1.AwsSsoIntegration(awsSsoIntegrations[i].id, awsSsoIntegrations[i].alias, awsSsoIntegrations[i].portalUrl, awsSsoIntegrations[i].region, awsSsoIntegrations[i].browserOpening, awsSsoIntegrations[i].accessTokenExpiration);
                }
                else {
                    newAwsSsoIntegration = awsSsoIntegrations[i];
                }
                newAwsSsoIntegrations.push(newAwsSsoIntegration);
            }
        }
        workspace._awsSsoIntegrations = newAwsSsoIntegrations;
        workspace._azureIntegrations = workspace._azureIntegrations || [];
        const azureSessions = workspace._sessions.filter((sess) => sess.type === session_type_1.SessionType.azure);
        workspace._sessions = workspace._sessions.filter((sess) => sess.type !== session_type_1.SessionType.azure);
        const defaultLocation = workspace.defaultLocation;
        const possibleNewIntegrations = [];
        azureSessions.forEach((sess) => {
            if (possibleNewIntegrations.map((ai) => ai.tenantId).indexOf(sess.tenantId) < 0) {
                // A new integration for Azure is found: add it to the list
                possibleNewIntegrations.push(new azure_integration_1.AzureIntegration(uuid.v4(), `AzureIntgr-${possibleNewIntegrations.length + 1}`, sess.tenantId, defaultLocation));
            }
        });
        workspace._azureIntegrations = workspace._azureIntegrations.concat(possibleNewIntegrations);
        this.reloadIntegrations(workspace);
    }
    reloadIntegrations(workspace) {
        this.persists(workspace);
        this.repository.reloadWorkspace();
        const updatedAwsSsoIntegrations = this.repository.listAwsSsoIntegrations();
        const updatedAzureIntegrations = this.repository.listAzureIntegrations();
        this.behaviouralSubjectService.setIntegrations([...updatedAwsSsoIntegrations, ...updatedAzureIntegrations]);
    }
    migration2() {
        const workspace = this.getWorkspace();
        if (!this.checkMigration(workspace, 1, 2)) {
            return;
        }
        workspace._pluginsStatus = [];
        this.persists(workspace);
        this.repository.reloadWorkspace();
    }
    migration3() {
        const workspace = this.getWorkspace();
        if (!this.checkMigration(workspace, 2, 3)) {
            return;
        }
        workspace.ssmRegionBehaviour = constants_1.constants.ssmRegionNo;
        this.persists(workspace);
        this.repository.reloadWorkspace();
    }
    migration4() {
        const workspace = this.getWorkspace();
        if (!this.checkMigration(workspace, 3, 4)) {
            return;
        }
        workspace.notifications = [];
        this.persists(workspace);
        this.repository.reloadWorkspace();
    }
    migration5() {
        const workspace = this.getWorkspace();
        if (!this.checkMigration(workspace, 4, 5)) {
            return;
        }
        const leappNotifications = this.repository.getNotifications();
        leappNotifications.forEach((notification) => {
            notification.popup = notification.uuid === "uuid";
        });
        workspace.notifications = leappNotifications;
        this.persists(workspace);
        this.repository.reloadWorkspace();
    }
    migration6() {
        const workspace = this.getWorkspace();
        if (!this.checkMigration(workspace, 5, 6)) {
            return;
        }
        workspace.requirePassword = constants_1.constants.requirePasswordEveryTwoWeeks.value;
        workspace.touchIdEnabled = constants_1.constants.touchIdEnabled;
        this.persists(workspace);
        this.repository.reloadWorkspace();
    }
    migration7() {
        const workspace = this.getWorkspace();
        if (!this.checkMigration(workspace, 6, 7)) {
            return;
        }
        workspace.remoteWorkspacesSettingsMap = {};
        this.persists(workspace);
        this.repository.reloadWorkspace();
    }
    getWorkspace() {
        const workspaceJSON = this.fileService.decryptText(this.fileService.readFileSync(this.lockFilePath));
        return JSON.parse(workspaceJSON);
    }
    persists(workspace) {
        this.fileService.writeFileSync(this.lockFilePath, this.fileService.encryptText((0, class_transformer_1.serialize)(workspace)));
    }
}
exports.RetroCompatibilityService = RetroCompatibilityService;
//# sourceMappingURL=retro-compatibility-service.js.map