"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SessionManagementService = void 0;
class SessionManagementService {
    constructor(repository, sessionFactory) {
        this.repository = repository;
        this.sessionFactory = sessionFactory;
    }
    getSessions() {
        return this.repository.getSessions();
    }
    getAssumableSessions() {
        return this.repository.listAssumable();
    }
    getActiveAndPendingSessions() {
        return this.repository.listActiveAndPending();
    }
    getActiveSessions() {
        return this.repository.listActive();
    }
    getPendingSessions() {
        return this.repository.listPending();
    }
    getSessionById(selectedSessionId) {
        return this.getSessions().find((s) => s.sessionId === selectedSessionId);
    }
    getIamRoleChained(session) {
        return this.repository.listIamRoleChained(session);
    }
    getAwsSsoRoles() {
        return this.repository.listAwsSsoRoles();
    }
    updateSessions(sessions) {
        this.repository.updateSessions(sessions);
    }
    updateSession(id, session) {
        this.repository.updateSession(id, session);
    }
    deleteSession(sessionId) {
        this.repository.deleteSession(sessionId);
    }
    async stopAllSessions() {
        const activeSessions = this.getActiveAndPendingSessions();
        for (const session of activeSessions) {
            const sessionService = this.sessionFactory.getSessionService(session.type);
            await sessionService.stop(session.sessionId);
        }
    }
}
exports.SessionManagementService = SessionManagementService;
//# sourceMappingURL=session-management-service.js.map