import { BrowserWindowClosing } from "../../../interfaces/i-browser-window-closing";
import { INativeService } from "../../../interfaces/i-native-service";
import { IBehaviouralNotifier } from "../../../interfaces/i-behavioural-notifier";
import { AwsSsoRoleSession } from "../../../models/aws/aws-sso-role-session";
import { CredentialsInfo } from "../../../models/credentials-info";
import { AwsCoreService } from "../../aws-core-service";
import { FileService } from "../../file-service";
import { Repository } from "../../repository";
import { AwsSessionService } from "./aws-session-service";
import { AwsSsoOidcService } from "../../aws-sso-oidc.service";
import { AwsSsoRoleSessionRequest } from "./aws-sso-role-session-request";
import { IAwsIntegrationDelegate } from "../../../interfaces/i-aws-integration-delegate";
import { IKeychainService } from "../../../interfaces/i-keychain-service";
import { CreateSessionRequest } from "../create-session-request";
import { GetRoleCredentialsResponse } from "@aws-sdk/client-sso";
export interface GenerateSSOTokenResponse {
    accessToken: string;
    expirationTime: Date;
}
export interface LoginResponse {
    accessToken: string;
    region: string;
    expirationTime: Date;
    portalUrlUnrolled: string;
}
export interface RegisterClientResponse {
    clientId?: string;
    clientSecret?: string;
    clientIdIssuedAt?: number;
    clientSecretExpiresAt?: number;
}
export interface StartDeviceAuthorizationResponse {
    deviceCode?: string;
    expiresIn?: number;
    interval?: number;
    userCode?: string;
    verificationUri?: string;
    verificationUriComplete?: string;
}
export interface VerificationResponse {
    clientId: string;
    clientSecret: string;
    deviceCode: string;
}
export interface SsoRoleSession {
    sessionName: string;
    roleArn: string;
    email: string;
    region: string;
    profileId: string;
    awsSsoConfigurationId: string;
}
export declare class AwsSsoRoleService extends AwsSessionService implements BrowserWindowClosing {
    protected sessionNotifier: IBehaviouralNotifier;
    protected repository: Repository;
    private keyChainService;
    private nativeService;
    private awsSsoOidcService;
    private awsIntegrationDelegate;
    constructor(sessionNotifier: IBehaviouralNotifier, repository: Repository, fileService: FileService, keyChainService: IKeychainService, awsCoreService: AwsCoreService, nativeService: INativeService, awsSsoOidcService: AwsSsoOidcService);
    static sessionTokenFromGetSessionTokenResponse(getRoleCredentialResponse: GetRoleCredentialsResponse): {
        sessionToken: any;
    };
    setAwsIntegrationDelegate(delegate: IAwsIntegrationDelegate): void;
    catchClosingBrowserWindow(): Promise<void>;
    create(request: AwsSsoRoleSessionRequest): Promise<void>;
    update(_: string, __: CreateSessionRequest): Promise<void>;
    applyCredentials(sessionId: string, credentialsInfo: CredentialsInfo): Promise<void>;
    deApplyCredentials(sessionId: string): Promise<void>;
    generateCredentialsProxy(sessionId: string): Promise<CredentialsInfo>;
    generateCredentials(sessionId: string): Promise<CredentialsInfo>;
    getAccountNumberFromCallerIdentity(session: AwsSsoRoleSession): Promise<string>;
    sessionDeactivated(sessionId: string): void;
    validateCredentials(sessionId: string): Promise<boolean>;
    removeSecrets(_: string): void;
    getCloneRequest(session: AwsSsoRoleSession): Promise<AwsSsoRoleSessionRequest>;
    private saveSessionTokenExpirationInTheSession;
}
