import { Session } from "../../models/session";
import { Repository } from "../repository";
import { IBehaviouralNotifier } from "../../interfaces/i-behavioural-notifier";
import { CreateSessionRequest } from "./create-session-request";
export declare abstract class SessionService {
    protected sessionNotifier: IBehaviouralNotifier;
    protected repository: Repository;
    protected constructor(sessionNotifier: IBehaviouralNotifier, repository: Repository);
    sessionDeactivated(sessionId: string): void;
    protected isInactive(sessionId: string): boolean;
    protected sessionActivated(sessionId: string, sessionTokenExpiration?: string): void;
    protected sessionLoading(sessionId: string): void;
    protected sessionError(sessionId: string, error: any): void;
    abstract create(sessionRequest: CreateSessionRequest): Promise<void>;
    abstract update(sessionId: string, updateRequest: CreateSessionRequest): Promise<void>;
    abstract start(sessionId: string): Promise<void>;
    abstract rotate(sessionId: string): Promise<void>;
    abstract stop(sessionId: string): Promise<void>;
    abstract delete(sessionId: string): Promise<void>;
    abstract getDependantSessions(sessionId: string): Session[];
    abstract validateCredentials(sessionId: string): Promise<boolean>;
    abstract getCloneRequest(session: Session): Promise<CreateSessionRequest>;
}
