import { ExecuteService } from "./execute-service";
import { CredentialsInfo } from "../models/credentials-info";
import { LogService } from "./log-service";
import { INativeService } from "../interfaces/i-native-service";
import { FileService } from "./file-service";
import { SSMClient } from "@aws-sdk/client-ssm";
import { EC2Client } from "@aws-sdk/client-ec2";
export declare class SsmService {
    private logService;
    private executeService;
    private nativeService;
    private fileService;
    ssmClient: SSMClient;
    ec2Client: EC2Client;
    constructor(logService: LogService, executeService: ExecuteService, nativeService: INativeService, fileService: FileService);
    /**
     * Set the config for the SSM client
     *
     * @param data - the credential information
     * @param region - the region for the client
     */
    static setConfig(data: CredentialsInfo, region: string): any;
    /**
     * Prepare the two clients and returns the available
     * ssm instances for the selected region
     *
     * @param credentials - pass the credentials object
     * @param region - pass the region where you want to make the request
     * @returns - {Observable<SsmResult>} - return the list of instances capable of SSM in the selected region
     */
    getSsmInstances(credentials: CredentialsInfo, region: string, setFilteringForEc2CallsCallback?: any): Promise<any>;
    /**
     * Start a new ssm session given the instance id
     *
     * @param credentials - CredentialsInfo data from generate credentials method
     * @param instanceId - the instance id of the instance to start
     * @param region - aws System Manager start a session from a defined region
     * @param macOsTerminalType - optional to override terminal type selection on macOS
     */
    startSession(credentials: CredentialsInfo, instanceId: string, region: string, macOsTerminalType?: string): void;
    /**
     * Submit the request to do ssm to aws
     */
    private requestSsmInstances;
    private applyEc2MetadataInformation;
}
