"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebConsoleService = void 0;
const log_service_1 = require("./log-service");
class WebConsoleService {
    constructor(shellService, logService, nativeService) {
        this.shellService = shellService;
        this.logService = logService;
        this.nativeService = nativeService;
        this.secondsInAHour = 3600;
        this.sessionDurationInHours = 12;
    }
    async getWebConsoleUrl(credentialsInfo, sessionRegion, sessionDuration = this.sessionDurationInHours * this.secondsInAHour) {
        const isUSGovCloud = sessionRegion.startsWith("us-gov-");
        let consoleHomeUrl;
        let signInUrl;
        if (!isUSGovCloud) {
            signInUrl = "https://us-east-1.signin.aws.amazon.com";
            consoleHomeUrl = `https://${sessionRegion}.console.aws.amazon.com/console/home?region=${sessionRegion}`;
        }
        else {
            signInUrl = "https://us-east-1.signin.amazonaws-us-gov.com";
            consoleHomeUrl = `https://console.amazonaws-us-gov.com/console/home?region=${sessionRegion}`;
        }
        const federationUrl = `${signInUrl}/federation`;
        const oAuthUrl = `${signInUrl}/oauth`;
        if (sessionRegion.startsWith("cn-")) {
            throw new Error("Unsupported Region");
        }
        this.logService.log(new log_service_1.LoggedEntry("Getting Web Console Url", this, log_service_1.LogLevel.info));
        const sessionStringJSON = {
            sessionId: credentialsInfo.sessionToken.aws_access_key_id,
            sessionKey: credentialsInfo.sessionToken.aws_secret_access_key,
            sessionToken: credentialsInfo.sessionToken.aws_session_token,
        };
        const queryParametersSigninToken = `?Action=getSigninToken&sessionDuration=${sessionDuration}&Session=${encodeURIComponent(JSON.stringify(sessionStringJSON))}`;
        const res = await this.nativeService.fetch(`${federationUrl}${queryParametersSigninToken}`);
        const response = await res.json();
        const redirectUrl = new URL(federationUrl);
        redirectUrl.searchParams.append("Action", "login");
        redirectUrl.searchParams.append("Issuer", "Leapp");
        redirectUrl.searchParams.append("Destination", consoleHomeUrl);
        redirectUrl.searchParams.append("SigninToken", response.SigninToken);
        const webConsoleUrl = new URL(oAuthUrl);
        webConsoleUrl.searchParams.append("Action", "logout");
        webConsoleUrl.searchParams.append("redirect_uri", redirectUrl.toString());
        return webConsoleUrl.toString();
    }
    async openWebConsole(credentialsInfo, sessionRegion, sessionDuration = this.sessionDurationInHours * this.secondsInAHour) {
        const loginURL = await this.getWebConsoleUrl(credentialsInfo, sessionRegion, sessionDuration);
        this.logService.log(new log_service_1.LoggedEntry("Opening Web Console in browser", this, log_service_1.LogLevel.info));
        this.shellService.openExternalUrl(loginURL);
    }
}
exports.WebConsoleService = WebConsoleService;
//# sourceMappingURL=web-console-service.js.map